@@ -84,17 +84,21 @@ def LoadPcap(pcap: str, **kwargs):
     # CEPTON_REPLAY_FLAG_LOAD_WITHOUT_INDEX = 1,
     # CEPTON_REPLAY_FLAG_PLAY_LOOPED = 2,
     # CEPTON_REPLAY_FLAG_LOAD_PAUSED = 4,
-    fl = 4 # Paused at load
+    flags = 0 # by default the pcap replays automatically and does not loop.
     speed = kwargs.get('speed', 100)
     if (kwargs.get('looping', False)):
-        fl |= 2 # looping
+        flags |= 2 # looping
+    if (kwargs.get('pause_on_load', False)):
+        flags |= 4 # paused on load
     # TODO: Check kwargs for bad parameters
 
     # Start of the actual actions
-    __check(_c.ReplayLoadPcap(pcap.encode('utf8'), fl,
+    __check(_c.ReplayLoadPcap(pcap.encode('utf8'), flags,
         _c.byref(__Sdk.replayHandle)))
     if (speed != 100):
         __check(_c.ReplaySetSpeed(__Sdk.replayHandle, speed))
+
+def ReplayPcap():
     __check(_c.ReplayPlay(__Sdk.replayHandle))
 
 def ReplayIsFinished():
@@ -122,7 +126,7 @@ def StopNetworking():
 def EnableFrameFifo(frameMode, nFrames):
     """
     Enable SDK frame FIFO feature.
-
+    
     Parameters
     ----------
     frameMode : int
